@@ -195,6 +195,8 @@ struct IndicatifSpanContext {
     // Used to quickly compute a child span's prefix without having to traverse up the entire span
     // scope.
     level: u16,
+    // If `Some`, this is the message that will be displayed when the progress bar is finished.
+    finish_message: Option<String>,
 }
 
 impl IndicatifSpanContext {
@@ -301,6 +303,28 @@ impl IndicatifSpanContext {
             pb.tick()
         }
     }
+
+    fn reset_progress_bar(&mut self) {
+        if let Some(ref pb) = self.progress_bar {
+            pb.reset();
+        }
+    }
+
+    fn reset_progress_bar_elapsed(&mut self) {
+        if let Some(ref pb) = self.progress_bar {
+            pb.reset_elapsed();
+        }
+    }
+
+    fn reset_progress_bar_eta(&mut self) {
+        if let Some(ref pb) = self.progress_bar {
+            pb.reset_eta();
+        }
+    }
+
+    fn set_progress_bar_finish_message(&mut self, msg: String) {
+        self.finish_message = Some(msg);
+    }
 }
 
 /// The layer that handles creating and managing indicatif progress bars for active spans. This
@@ -667,6 +691,7 @@ where
             span_name: span.name().to_string(),
             span_child_prefix,
             level,
+            finish_message: None,
         });
     }
 
